==> api_guide-1.1.0.tar.gz: lib/src/presentation/widgets/helpers/close_dialog_btn.dart <==
/// Copyright © 2023, Oct. Developed by Mouaz M. Al-Shahmeh
/// https://malshahmeh.web.app
/// APIGuide package

/// Import necessary packages
/// Import [flutter/material] package files
import 'package:flutter/material.dart';

/// Import [provider] package files
import 'package:provider/provider.dart';

/// Import [APIGuide] package files
import '../../../../api_guide.dart';

/// Close Search Dialog Button from type of [ElevatedButton]
ElevatedButton closeSearchDialogButton(
  /// BuildContext
  BuildContext context,
) {
  /// ThemeNotifierProvider to check theme attributes' states
  final themeState = context.read<ThemeProvider>();

  /// SearchNotifierProvider to check theme attributes' states
  final searchState = context.read<SearchProvider>();

  return ElevatedButton(
    style: ButtonStyle(
      backgroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        themeState.isDarkMode
            ? ConstantsDarkMode.themeColor(context)
            : ConstantsLightMode.themeColor(context),
      ),
      foregroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        themeState.isDarkMode
            ? ConstantsDarkMode.whiteColor
            : ConstantsLightMode.whiteColor,
      ),
      textStyle: MaterialStateProperty.all(
        TextStyle(
          fontSize: Constants.size10,

          /// Check the current light/dark theme mode
          color: themeState.isDarkMode
              ? ConstantsDarkMode.greyLightColor
              : ConstantsLightMode.greyLightColor,
        ),
      ),
    ),
    onPressed: () {
      /// Toggle the [_isOpened] state
      searchState.updateIsOpenSearch(false);
    },
    child: Text(Constants.closeTxt),
  );
}

/// Close Sample Code Dialog Button from type of [ElevatedButton]
ElevatedButton closeSampleCodeDialogButton(
  /// BuildContext
  BuildContext context,
) {
  /// ThemeNotifierProvider to check theme attributes' states
  final themeState = context.read<ThemeProvider>();

  /// AppNotifierProvider to check theme attributes' states
  final appState = context.read<AppProvider>();

  return ElevatedButton(
    style: ButtonStyle(
      backgroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        themeState.isDarkMode
            ? ConstantsDarkMode.themeColor(context)
            : ConstantsLightMode.themeColor(context),
      ),
      foregroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        themeState.isDarkMode
            ? ConstantsDarkMode.whiteColor
            : ConstantsLightMode.whiteColor,
      ),
      textStyle: MaterialStateProperty.all(
        TextStyle(
          fontSize: Constants.size10,

          /// Check the current light/dark theme mode
          color: themeState.isDarkMode
              ? ConstantsDarkMode.greyLightColor
              : ConstantsLightMode.greyLightColor,
        ),
      ),
    ),
    onPressed: () {
      /// Toggle the [_isOpened] state
      appState.updateIsOpenSampleCode(false);
    },
    child: Text(Constants.closeTxt),
  );
}

/// Close Server Dialog Button from type of [ElevatedButton]
ElevatedButton closeServerDialogButton(
  /// BuildContext
  BuildContext context,
) {
  /// ThemeNotifierProvider to check theme attributes' states
  final themeState = context.read<ThemeProvider>();

  /// AppNotifierProvider to check theme attributes' states
  final appState = context.read<AppProvider>();

  return ElevatedButton(
    style: ButtonStyle(
      backgroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        themeState.isDarkMode
            ? ConstantsDarkMode.themeColor(context)
            : ConstantsLightMode.themeColor(context),
      ),
      foregroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        themeState.isDarkMode
            ? ConstantsDarkMode.whiteColor
            : ConstantsLightMode.whiteColor,
      ),
      textStyle: MaterialStateProperty.all(
        TextStyle(
          fontSize: Constants.size10,

          /// Check the current light/dark theme mode
          color: themeState.isDarkMode
              ? ConstantsDarkMode.greyLightColor
              : ConstantsLightMode.greyLightColor,
        ),
      ),
    ),
    onPressed: () {
      /// Toggle the [_isOpened] state
      appState.updateIsOpenServer(false);
    },
    child: Text(Constants.closeTxt),
  );
}

==> api_guide-1.1.7.tar.gz: lib/src/presentation/widgets/helpers/close_dialog_btn.dart <==
import 'package:flutter/material.dart';

/// Import [flutter_riverpod] package files
import 'package:flutter_riverpod/flutter_riverpod.dart';

/// Import [APIGuide] package files
import '../../../../api_guide.dart';

/// Close Search Dialog Button from type of [ElevatedButton]
ElevatedButton closeSearchDialogButton(
  /// WidgetRef
  WidgetRef ref,
) {
  /// isDarkModeProvider to check theme attributes' states
  final isDarkMode = ref.watch(isDarkModeProvider);

  return ElevatedButton(
    style: ButtonStyle(
      backgroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        isDarkMode
            ? ConstantsDarkMode.themeColor(ref)
            : ConstantsLightMode.themeColor(ref),
      ),
      foregroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        isDarkMode
            ? ConstantsDarkMode.whiteColor
            : ConstantsLightMode.whiteColor,
      ),
      textStyle: MaterialStateProperty.all(
        TextStyle(
          fontSize: Constants.size10,

          /// Check the current light/dark theme mode
          color: isDarkMode
              ? ConstantsDarkMode.greyLightColor
              : ConstantsLightMode.greyLightColor,
        ),
      ),
    ),
    onPressed: () {
      /// Reset the isOpened state
      ref.read(isOpenSearchProvider.notifier).state = false;
    },
    child: Text(Constants.closeTxt),
  );
}

/// Close Sample Code Dialog Button from type of [ElevatedButton]
ElevatedButton closeSampleCodeDialogButton(
  /// WidgetRef
  WidgetRef ref,
) {
  /// isDarkModeProvider to check theme attributes' states
  final isDarkMode = ref.watch(isDarkModeProvider);

  return ElevatedButton(
    style: ButtonStyle(
      backgroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        isDarkMode
            ? ConstantsDarkMode.themeColor(ref)
            : ConstantsLightMode.themeColor(ref),
      ),
      foregroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        isDarkMode
            ? ConstantsDarkMode.whiteColor
            : ConstantsLightMode.whiteColor,
      ),
      textStyle: MaterialStateProperty.all(
        TextStyle(
          fontSize: Constants.size10,

          /// Check the current light/dark theme mode
          color: isDarkMode
              ? ConstantsDarkMode.greyLightColor
              : ConstantsLightMode.greyLightColor,
        ),
      ),
    ),
    onPressed: () {
      /// Toggle the [_isOpened] state
      ref.read(isOpenSampleCodeProvider.notifier).state = false;
    },
    child: Text(Constants.closeTxt),
  );
}

/// Close Server Dialog Button from type of [ElevatedButton]
ElevatedButton closeServerDialogButton(
  /// WidgetRef
  WidgetRef ref,
) {
  /// isDarkModeProvider to check theme attributes' states
  final isDarkMode = ref.watch(isDarkModeProvider);

  return ElevatedButton(
    style: ButtonStyle(
      backgroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        isDarkMode
            ? ConstantsDarkMode.themeColor(ref)
            : ConstantsLightMode.themeColor(ref),
      ),
      foregroundColor: MaterialStateProperty.all(
        /// Check the current light/dark theme mode
        isDarkMode
            ? ConstantsDarkMode.whiteColor
            : ConstantsLightMode.whiteColor,
      ),
      textStyle: MaterialStateProperty.all(
        TextStyle(
          fontSize: Constants.size10,

          /// Check the current light/dark theme mode
          color: isDarkMode
              ? ConstantsDarkMode.greyLightColor
              : ConstantsLightMode.greyLightColor,
        ),
      ),
    ),
    onPressed: () {
      /// Toggle the [_isOpened] state
      ref.read(isOpenServerProvider.notifier).state = false;
    },
    child: Text(Constants.closeTxt),
  );
}
